@@ -52,6 +52,12 @@ class color:
     def toning(R:int = 0, G:int = 0, B:int = 0):
         return f"\033[38;2;{R};{G};{B}m"
 
+    def string_addtoning():
+        import builtins
+        class toningit(str):
+            def toning(self, R:int = 0, G:int = 0, B:int = 0):
+                return f"\033[38;2;{R};{G};{B}m" + self + "\033[0m"
+        builtins.str = toningit
 
 
 
